cheesecake.cheesecake_index.StepByVariable

Package cheesecake :: Module cheesecake_index :: Class StepByVariable |
[hide private]
[frames] | no frames]

## Class StepByVariable
source code

    object --+
             |
          Step --+
                 |
                StepByVariable

Step which is always run if given Cheesecake instance variable is true.

Instance Methods | [hide private]
| __init__(self, variable_name, provides)
| decide(self, cheesecake) Decide if step should be run.
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, variable_name, provides) (Constructor) | source code
Overrides: Step.__init__

### decide(self, cheesecake) | source code
Decide if step should be run. It checks if there's at least one index from current profile that need variables provided by this step. Override this method for other behaviour. Overrides: Step.decide (inherited documentation)